use clap::{arg, Parser};
//use docker_tags::docker::DockerHubTagsFetcher;
use docker_tags::{DockerTags, QueryArgs};
use docker_tags::registry::RegistryTagsFetcher;

#[derive(Parser, Debug)]
#[command(name = "dockertags", author, version, about = "List all tags for a Docker image on a remote registry", long_about = "List all tags for a Docker image on a remote registry")]
struct Args {
    /// docker image name
    #[arg(value_name = "REPOSITORY")]
    repository: Option<String>,
    /// docker image architecture
    #[arg(short, long, value_name = "ARCHITECTURE")]
    arch: Option<String>,
    /// image tags name to filter
    #[arg(short, long, value_name = "TAG")]
    name: Option<String>,
}


fn main() {
    let args = Args::parse();
    let query_args = QueryArgs {
        repository: args.repository,
        name: args.name,
        arch: args.arch,
    };
    // let docker_tags_fetcher = DockerHubTagsFetcher {};
    let docker_tags_fetcher = RegistryTagsFetcher {};
    let tags = docker_tags_fetcher.get_tags(&query_args);

    for tag in tags {
        println!("{}", &tag)
    }
}
